@@ -217,7 +217,7 @@ void KControlHeader::init()
     // set a sensible focus
     _headerTitle->setFocus();
 
-    this->setMainWidget(mainView);
+    setMainWidget(mainView);
 }
 
 /** Insert header */
@@ -300,7 +300,7 @@ void KControlHeader::slotOk()
 {
     insertHeader();
     configWrite();
-    this->accept();
+    accept();
 }
 
 /** Read settings */
@@ -362,7 +362,7 @@ void KControlHeader::configRead()
 
     appconfig->setGroup("kcontrolheader");
     QSize *defaultSize = new QSize(500,400);
-    this->resize( appconfig->readSizeEntry("Geometry", defaultSize ) );
+    resize( appconfig->readSizeEntry("Geometry", defaultSize ) );
     delete config;
 }
 
@@ -371,6 +371,6 @@ void KControlHeader::configWrite()
 {
     KConfig *config = KGlobal::config();
     config->setGroup("kcontrolheader");
-    config->writeEntry("Geometry", this->size() );
+    config->writeEntry("Geometry", size() );
     config->sync();
 }
