@@ -24,7 +24,7 @@
 #include "keducabuilder.h"
 
 static const char description[] = I18N_NOOP("Form-based tests and exams builder");
-static const char version[]     = I18N_NOOP("1.2.0");
+static const char version[]     = "1.2.0";
 
 static KCmdLineOptions options[] =
 {
@@ -37,9 +37,10 @@ int main(int argc, char *argv[])
     KAboutData aboutData( "keduca", I18N_NOOP("KEducaBuilder"),
                           version, description, KAboutData::License_GPL,
                           "(c) 2001, Javier Campos", 0, "http://keduca.sourceforge.net", "submit@bugs.kde.org");
-    aboutData.addAuthor("Javier Campos","Original Author", "javi@asyris.org");
-    aboutData.addAuthor("Klas Kalass","Current Maintainer", "klas@kde.org");
-    aboutData.addAuthor("Anne-Marie Mahfouf","Various fixes and cleanups", "annma@kde.org");
+    aboutData.addAuthor("Javier Campos",I18N_NOOP("Original Author"), "javi@asyris.org");
+    aboutData.addAuthor("Klas Kalass",I18N_NOOP("Maintainer 2002-2004"), "klas@kde.org");
+    aboutData.addAuthor("Anne-Marie Mahfouf",I18N_NOOP("Various fixes and cleanups"), "annma@kde.org");
+    aboutData.addCredit("Nenad Grujicic", I18N_NOOP("Icons"), "mengele@linuxo.org");
     KCmdLineArgs::init( argc, argv, &aboutData );
     KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.
 
