@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301
    USA
 **/
 
@@ -198,7 +198,6 @@ void KigPainter::textOverlay( const QRect& r, const QString s, int textFlags, in
 {
   //  kdDebug() << Rect::fromQRect( mP.boundingRect( r, textFlags, s, len ) ) << endl;
   QRect newr( mP.boundingRect( r, textFlags, s, len ) );
-  newr.moveBy( -2, -2 );
   newr.setWidth( newr.width() + 4 );
   newr.setHeight( newr.height() + 4 );
   mOverlay.push_back( newr );
@@ -208,7 +207,6 @@ const Rect KigPainter::boundingRect( const Rect& r, const QString s,
                                      int f, int l ) const
 {
   QRect qr = mP.boundingRect( toScreen( r ), f, s, l );
-  qr.moveBy( -2, -2 );
   qr.setWidth( qr.width() + 4 );
   qr.setHeight( qr.height() + 4 );
   return fromScreen( qr );
@@ -509,7 +507,7 @@ void KigPainter::drawFilledRect( const QRect& r )
 
 void KigPainter::drawTextStd( const QPoint& p, const QString& s )
 {
-  if ( ! s ) return;
+  if ( s.isNull() ) return;
   // tf = text formatting flags
   int tf = AlignLeft | AlignTop | DontClip | WordBreak;
   // we need the rect where we're going to paint text
@@ -680,8 +678,12 @@ void KigPainter::drawVector( const Coordinate& a, const Coordinate& b )
   dir /= length;
   Coordinate c = b - dir + perp;
   Coordinate d = b - dir - perp;
+  // draw the arrow lines with a normal style
+  mP.setPen( QPen( color, width == -1 ? 1 : width, Qt::SolidLine ) );
   drawSegment( b, c );
   drawSegment( b, d );
+  // setting again the original style
+  mP.setPen( QPen( color, width == -1 ? 1 : width, style ) );
 }
 
 /* *** this function is commented out ***
@@ -932,11 +934,20 @@ void KigPainter::drawArc( const Coordinate& center, const double radius,
   const int startangle = static_cast<int>( Goniometry::convert( 16 * dstartangle, Goniometry::Rad, Goniometry::Deg ) );
   const int angle = static_cast<int>( Goniometry::convert( 16 * dangle, Goniometry::Rad, Goniometry::Deg ) );
 
-  Rect krect( 0, 0, 2*radius, 2*radius );
-  krect.setCenter( center );
-  QRect rect = toScreen( krect );
+  if ( angle <= 16 )
+  {
+    Coordinate a = center + radius * Coordinate( cos( dstartangle ), sin( dstartangle ));
+    Coordinate b = center + radius * Coordinate( cos( dstartangle + dangle ), sin( dstartangle + dangle ));
+    drawSegment ( a , b );
+  } 
+  else
+  { 
+    Rect krect( 0, 0, 2*radius, 2*radius );
+    krect.setCenter( center );
+    QRect rect = toScreen( krect );
 
-  mP.drawArc( rect, startangle, angle );
-  setWholeWinOverlay();
+    mP.drawArc( rect, startangle, angle );
+    setWholeWinOverlay();
+  }
 }
 
