@@ -12,8 +12,8 @@
 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-// 02111-1307, USA.
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+// 02110-1301, USA.
 
 #include "special_constructors.h"
 
@@ -296,7 +296,7 @@ const QString PolygonBNPTypeConstructor::description() const
 
 const QCString PolygonBNPTypeConstructor::iconFileName( const bool ) const
 {
-  return "polygon";
+  return "kig_polygon";
 }
 
 const bool PolygonBNPTypeConstructor::isAlreadySelectedOK(
@@ -1058,14 +1058,28 @@ InversionConstructor::InversionConstructor()
       "SHOULDNOTBESEEN", "SHOULDNOTBESEEN",
       "inversion" );
 
+  SimpleObjectTypeConstructor* segmentobj =
+     new SimpleObjectTypeConstructor(
+      InvertSegmentType::instance(),
+      "SHOULDNOTBESEEN", "SHOULDNOTBESEEN",
+      "inversion" );
+
   SimpleObjectTypeConstructor* circleobj =
      new SimpleObjectTypeConstructor(
       InvertCircleType::instance(),
       "SHOULDNOTBESEEN", "SHOULDNOTBESEEN",
       "inversion" );
 
+  SimpleObjectTypeConstructor* arcobj =
+     new SimpleObjectTypeConstructor(
+      InvertArcType::instance(),
+      "SHOULDNOTBESEEN", "SHOULDNOTBESEEN",
+      "inversion" );
+
+  merge( arcobj );
   merge( circleobj );
   merge( pointobj );
+  merge( segmentobj );
   merge( lineobj );
 }
 
