@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301
    USA
 **/
 
@@ -33,6 +33,7 @@
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kpushbutton.h>
+#include <kstdguiitem.h>
 
 #include <qfile.h>
 #include <qpixmap.h>
@@ -61,9 +62,10 @@ TypesDialog::TypesDialog( QWidget* parent, KigPart& part )
   : TypesDialogBase( parent, "types_dialog", true ), mpart( part )
 {
   // improving GUI look'n'feel...
+  buttonHelp->setGuiItem( KStdGuiItem::help() );
+  buttonOk->setGuiItem( KStdGuiItem::ok() );
+  buttonCancel->setGuiItem( KStdGuiItem::cancel() );
   il = part.instance()->iconLoader();
-  buttonHelp->setIconSet( QIconSet( il->loadIcon( "help", KIcon::Small ) ) );
-  buttonOk->setIconSet( QIconSet( il->loadIcon( "button_ok", KIcon::Small ) ) );
   buttonEdit->setIconSet( QIconSet( il->loadIcon( "edit", KIcon::Small ) ) );
   buttonRemove->setIconSet( QIconSet( il->loadIcon( "editdelete", KIcon::Small ) ) );
   buttonExport->setIconSet( QIconSet( il->loadIcon( "fileexport", KIcon::Small ) ) );
@@ -75,6 +77,15 @@ TypesDialog::TypesDialog( QWidget* parent, KigPart& part )
 
   // loading macros...
   loadAllMacros();
+
+  popup = new QPopupMenu( this );
+  popup->insertItem( SmallIcon( "edit" ), i18n( "&Edit..." ), this, SLOT( editType() ) );
+  popup->insertItem( SmallIcon( "editdelete" ), i18n( "&Delete" ), this, SLOT( deleteType() ) );
+  popup->insertSeparator();
+  popup->insertItem( SmallIcon( "fileexport" ), i18n( "E&xport..." ), this, SLOT( exportType() ) );
+
+  // saving types
+  part.saveTypes();
 }
 
 QListViewItem* TypesDialog::newListItem( Macro* m )
@@ -101,6 +112,9 @@ void TypesDialog::helpSlot()
 
 void TypesDialog::okSlot()
 {
+  mpart.saveTypes();
+  mpart.deleteTypes();
+  mpart.loadTypes();
   accept();
 }
 
@@ -156,9 +170,9 @@ void TypesDialog::exportType()
     return;
   QFile fi( file_name );
   if ( fi.exists() )
-    if ( KMessageBox::questionYesNo( this, i18n( "The file \"%1\" already exists. "
+    if ( KMessageBox::warningContinueCancel( this, i18n( "The file \"%1\" already exists. "
                                        "Do you wish to overwrite it?" ).arg( fi.name() ),
-                                       i18n( "Overwrite File?" ) ) == KMessageBox::No )
+                                       i18n( "Overwrite File?" ), i18n("Overwrite") ) == KMessageBox::Cancel )
        return;
   MacroList::instance()->save( types, file_name );
 }
@@ -246,6 +260,11 @@ void TypesDialog::editType()
   delete d;
 }
 
+void TypesDialog::contextMenuRequested( QListViewItem*, const QPoint& p, int )
+{
+  popup->exec( p );
+}
+
 void TypesDialog::loadAllMacros()
 {
   const vec& macros = MacroList::instance()->macros();
@@ -254,3 +273,10 @@ void TypesDialog::loadAllMacros()
     typeList->insertItem( newListItem( *i ) );
   }
 }
+
+void TypesDialog::cancelSlot()
+{
+  mpart.deleteTypes();
+  mpart.loadTypes();
+  reject();
+}
