@@ -447,7 +447,7 @@ void KLettres::slotModeKid()
 void KLettres::loadLangToolBar()
 {
     m_secondToolbar->clear();
-    if (m_languages[Prefs::languageNumber()]== "cs" || m_languages[Prefs::languageNumber()]== "da" || m_languages[Prefs::languageNumber()]== "sk" || m_languages[Prefs::languageNumber()]== "es")//Dutch, English, French and Italian have no special characters
+    if (m_languages[Prefs::languageNumber()]== "cs" || m_languages[Prefs::languageNumber()]== "da" || m_languages[Prefs::languageNumber()]== "sk" || m_languages[Prefs::languageNumber()]== "es" || m_languages[Prefs::languageNumber()]== "de")//Dutch, English, French and Italian have no special characters
     {
         allData.clear();
         QString myString=QString("klettres/%1.txt").arg(m_languages[Prefs::languageNumber()]);
@@ -481,7 +481,7 @@ void KLettres::loadLangToolBar()
 void KLettres::slotPasteChar()
 {
         KToolBarButton *charBut = (KToolBarButton* ) sender();
-        m_view->m_letterEdit->setText(allData[charBut->id()]);
+        m_view->m_letterEdit->insert(allData[charBut->id()]);
 }
 
 QString KLettres::charIcon(const QChar & c)
