@@ -77,7 +77,7 @@ public:
 
 /**@short Update object name and coordinates in the Focus InfoBox
 	*/
-	void showFocusCoords();
+	void showFocusCoords( bool coordsOnly = false );
 
 /**@short Update the focus position according to current options.
 	*/
@@ -554,11 +554,11 @@ protected:
 	*@li +/- keys  Zoom in and out 
 	*@li N/E/S/W keys  Go to the cardinal points on the Horizon
 	*@li Z  Go to the Zenith
-	*@li <Space>  Toggle between Horizontal and Equatorial coordinate systems
+	*@li <i>Space</i>  Toggle between Horizontal and Equatorial coordinate systems
 	*@li 0-9  Go to a major Solar System body (0=Sun; 1-9 are the major planets, except 3=Moon)
 	*@li [  Place starting point for measuring an angular distance
 	*@li ]  End point for Angular Distance; display measurement.
-	*@li <Escape>  Cancel Angular measurement
+	*@li <i>Escape</i>  Cancel Angular measurement
 	*@li ,/<  Step backward one time step
 	*@li ./>  Step forward one time step
 	*/
@@ -657,11 +657,10 @@ private:
 	
 /**@short Draw the Horizon Line, the compass point labels, and the opaque ground.
 	*@param psky reference to the QPainter on which to draw (either the sky pixmap or printer device)
-	*@param stdFont The font to be used for the compass point labels (DEPRECATE)
 	*@param scale the scaling factor.  We use the default value (1.0) everywhere, except when printing.
 	*/
 	
-	void drawHorizon( QPainter& psky, QFont& stdFont, double scale = 1.0 );
+	void drawHorizon( QPainter& psky, double scale = 1.0 );
 /**@short Draw the Constellation Lines.
 	*@param psky reference to the QPainter on which to draw (either the sky pixmap or printer device)
 	*@param scale the scaling factor.  We use the default value (1.0) everywhere, except when printing.
@@ -678,7 +677,7 @@ private:
 	*@param psky reference to the QPainter on which to draw (either the sky pixmap or printer device)
 	*@param scale the scaling factor.  We use the default value (1.0) everywhere, except when printing.
 	*/
-	void drawConstellationNames( QPainter& psky, QFont& stdFont, double scale = 1.0 );
+	void drawConstellationNames( QPainter& psky, double scale = 1.0 );
 	
 /**@short Draw the Stars.
 	*@param psky reference to the QPainter on which to draw (either the sky pixmap or printer device)
@@ -783,6 +782,12 @@ private:
 	*/
 	void drawTelescopeSymbols(QPainter &psky);
 	
+/**@short Draw symbols for objects in the observing list.
+	*@param psky reference to the QPainter on which to draw (this should be the sky pixmap)
+	*@note there is no scale factor because this is only used for drawing onto the screen, not printing.
+	*/
+	void drawObservingList( QPainter &psky, double scale = 1.0 );
+
 /**Draw a dotted-line rectangle which traces the potential new field-of-view in ZoomBox mode.
 	*@param psky reference to the QPainter on which to draw (this should be the Sky pixmap). 
 	*@note there is no scale factor because this is only used for drawing onto the screen, not printing.
@@ -934,7 +939,7 @@ private:
 	KStars *ksw;
 	KStarsData *data;
 	KSPopupMenu *pmenu;
-	QPixmap *sky;
+	QPixmap *sky, *sky2;
 	InfoBoxes  *IBoxes;
 	SkyPoint  Focus, OldFocus, ClickedPoint, FocusPoint, MousePoint, Destination, PreviousClickedPoint;
 	SkyObject *ClickedObject, *FocusObject, *TransientObject;
