@@ -49,6 +49,7 @@ void SkyMap::resizeEvent( QResizeEvent * )
 		infoBoxes()->resize( width(), height() );
 	}
 	sky->resize( width(), height() );
+	sky2->resize( width(), height() );
 }
 
 void SkyMap::keyPressEvent( QKeyEvent *e ) {
@@ -422,7 +423,7 @@ void SkyMap::keyReleaseEvent( QKeyEvent *e ) {
 			else
 				setDestination( focus() );
 
-			showFocusCoords();
+			showFocusCoords( true );
 			forceUpdate();	// Need a full update to draw faint objects that are not drawn while slewing.
 			break;
 	}
@@ -505,7 +506,7 @@ void SkyMap::mouseMoveEvent( QMouseEvent *e ) {
 		if (!slewing) {
 			slewing = true;
 			infoBoxes()->focusObjChanged( i18n( "nothing" ) );
-			if ( ksw && Options::isTracking() ) ksw->slotTrack(); //toggle tracking off
+			stopTracking(); //toggle tracking off
 		}
 
 		//Update focus such that the sky coords at mouse cursor remain approximately constant
@@ -535,7 +536,7 @@ void SkyMap::mouseMoveEvent( QMouseEvent *e ) {
 
 		++scrollCount;
 		if ( scrollCount > 4 ) {
-			showFocusCoords();
+			showFocusCoords( true );
 			scrollCount = 0;
 		}
 
@@ -555,7 +556,10 @@ void SkyMap::mouseMoveEvent( QMouseEvent *e ) {
 		if ( ksw ) {
 			QString sX, sY, s;
 			sX = mousePoint()->az()->toDMSString(true);  //true = force +/- symbol
-			sY = mousePoint()->alt()->toDMSString(true); //true = force +/- symbol
+			sY = mousePoint()->alt()->toDMSString(true); //true=force +/- symbol
+			if ( Options::useAltAz() && Options::useRefraction() ) 
+				sY = refract( mousePoint()->alt(), true ).toDMSString(true);
+
 			s = sX + ",  " + sY;
 			ksw->statusBar()->changeItem( s, 1 );
 			
@@ -586,13 +590,13 @@ void SkyMap::mouseReleaseEvent( QMouseEvent * ) {
 		double dx = ( 0.5*width()  - ZoomRect.center().x() )/Options::zoomFactor();
 		double dy = ( 0.5*height() - ZoomRect.center().y() )/Options::zoomFactor();
 
+		infoBoxes()->focusObjChanged( i18n( "nothing" ) );
+		stopTracking();
+
 		SkyPoint newcenter = dXdYToRaDec( dx, dy, Options::useAltAz(), data->LST, data->geo()->lat(), Options::useRefraction() );
-		setClickedPoint( &newcenter );
-		setClickedObject( NULL );
-		setFocusObject( NULL );
+
 		setFocus( &newcenter );
 		setDestination( &newcenter );
-		setOldFocus( &newcenter );
 		ksw->zoom( Options::zoomFactor() * factor );
 		
 		setDefaultMouseCursor();
@@ -726,10 +730,9 @@ void SkyMap::paintEvent( QPaintEvent * )
 	//of the skymap, use forceUpdate().
 	if (!computeSkymap)
 	{
-		QPixmap *sky2 = new QPixmap( *sky );
+		*sky2 = *sky;
 		drawOverlays( sky2 );
 		bitBlt( this, 0, 0, sky2 );
-		delete sky2;
 		return ; // exit because the pixmap is repainted and that's all what we want
 	}
 
@@ -753,41 +756,29 @@ void SkyMap::paintEvent( QPaintEvent * )
 	psky.begin( sky );
 	psky.fillRect( 0, 0, width(), height(), QBrush( data->colorScheme()->colorNamed( "SkyColor" ) ) );
 
-	QFont stdFont = psky.font();
-	QFont smallFont = psky.font();
-	smallFont.setPointSize( stdFont.pointSize() - 2 );
-
 	if ( drawMW ) drawMilkyWay( psky );
 	if ( drawGrid ) drawCoordinateGrid( psky );
 	
 	if ( drawCBounds ) drawConstellationBoundaries( psky );
 	if ( drawCLines ) drawConstellationLines( psky );
-	if ( drawCNames ) drawConstellationNames( psky, stdFont );
+	if ( drawCNames ) drawConstellationNames( psky );
 
 	if ( Options::showEquator() ) drawEquator( psky );
 	if ( Options::showEcliptic() ) drawEcliptic( psky );
 
-	// stars and planets use the same font size
-	if ( Options::zoomFactor() < 10.*MINZOOM ) {
-		psky.setFont( smallFont );
-	} else {
-		psky.setFont( stdFont );
-	}
-
 	//drawing to screen, so leave scale parameter at its default value of 1.0
 	drawStars( psky );
 	drawDeepSkyObjects( psky );
 	drawSolarSystem( psky, drawPlanets );
 	drawAttachedLabels( psky );
-	drawHorizon( psky, stdFont );
+	drawHorizon( psky );
 
 	//Finish up
 	psky.end();
 
-	QPixmap *sky2 = new QPixmap( *sky );
+	*sky2 = *sky;
 	drawOverlays( sky2 );
 	bitBlt( this, 0, 0, sky2 );
-	delete sky2;
 
 	computeSkymap = false;	// use forceUpdate() to compute new skymap else old pixmap will be shown
 }
