@@ -25,6 +25,7 @@
 //33-41: 1 year, 2, 3, 4, 5, 10, 25, 50, 100 years
 
 #include <qlineedit.h>
+#include <qfontmetrics.h>
 #include <kdebug.h>
 #include <klocale.h>
 #include <stdlib.h>
@@ -36,79 +37,111 @@
 #define SIDEREAL_YEAR 31558149.77
 #define TROPICAL_YEAR 31556925.19
 
-TimeSpinBox::TimeSpinBox( QWidget *parent, const char *name )
+TimeSpinBox::TimeSpinBox( QWidget *parent, const char *name, bool _daysonly )
 	: QSpinBox ( -41, 41, 1 /* step */, parent, name )
 {
 	setValidator( 0 );
 	setButtonSymbols( QSpinBox::PlusMinus );
 	editor()->setReadOnly( true );
 	setValue( 4 ); //1 second (real time)
+	setDaysOnly( _daysonly );
 
+	//Set width:
+	QFontMetrics fm( font() );
+	int extra = width() - editor()->width();
+	uint wmax = 0;
+	for ( int i=0; i < maxValue(); ++i ) {
+		uint w = fm.width( "-" + TimeString[i] );
+		if (  w > wmax ) wmax = w;
+	}
+	setFixedWidth( wmax + extra );
+
+	connect( this, SIGNAL( valueChanged( int ) ), this, SLOT( reportChange() ) );
+	updateDisplay();
+}
+
+void TimeSpinBox::setDaysOnly( bool daysonly ) {
+	DaysOnly = daysonly;
+
+	int i=0; //index for TimeScale values
 	TimeScale[0] = 0.0;          // 0.0 sec
-	TimeScale[1] = 0.1;          // 0.1 sec
-	TimeScale[2] = 0.25;         // 0.25 sec
-	TimeScale[3] = 0.5;          // 0.5 sec 
-	TimeScale[4] = 1.0;          // 1 sec (real-time)
-	TimeScale[5] = 2.0;          // 2 sec
-	TimeScale[6] = 5.0;          // 5 sec
-	TimeScale[7] = 10.0;         // 10 sec
-	TimeScale[8] = 20.0;         // 20 sec
-	TimeScale[9] = 30.0;         // 30 sec
-	TimeScale[10] = 60.0;        // 1 min
-	TimeScale[11] = 120.0;       // 2 min
-	TimeScale[12] = 300.0;       // 5 min
-	TimeScale[13] = 600.0;       // 10 min
-	TimeScale[14] = 900.0;       // 15 min
-	TimeScale[15] = 1800.0;      // 30 min
-	TimeScale[16] = 3600.0;      // 1 hr
-	TimeScale[17] = 7200.0;      // 2 hr
-	TimeScale[18] = 10800.0;     // 3 hr
-	TimeScale[19] = 21600.0;     // 6 hr
-	TimeScale[20] = 43200.0;     // 12 hr
-	TimeScale[21] = SECS_PER_DAY;     // 1 day
-	TimeScale[22] = 2.*SECS_PER_DAY;  // 2 days
-	TimeScale[23] = 3.*SECS_PER_DAY;  // 3 days
-	TimeScale[24] = 5.*SECS_PER_DAY;  // 5 days
-	TimeScale[25] = 7.*SECS_PER_DAY;  // 1 week
-	TimeScale[26] = 14.*SECS_PER_DAY; //2 weeks
-	TimeScale[27] = 21.*SECS_PER_DAY; //3 weeks    
+	if ( ! daysOnly() ) {
+		TimeScale[1] = 0.1;          // 0.1 sec
+		TimeScale[2] = 0.25;         // 0.25 sec
+		TimeScale[3] = 0.5;          // 0.5 sec 
+		TimeScale[4] = 1.0;          // 1 sec (real-time)
+		TimeScale[5] = 2.0;          // 2 sec
+		TimeScale[6] = 5.0;          // 5 sec
+		TimeScale[7] = 10.0;         // 10 sec
+		TimeScale[8] = 20.0;         // 20 sec
+		TimeScale[9] = 30.0;         // 30 sec
+		TimeScale[10] = 60.0;        // 1 min
+		TimeScale[11] = 120.0;       // 2 min
+		TimeScale[12] = 300.0;       // 5 min
+		TimeScale[13] = 600.0;       // 10 min
+		TimeScale[14] = 900.0;       // 15 min
+		TimeScale[15] = 1800.0;      // 30 min
+		TimeScale[16] = 3600.0;      // 1 hr
+		TimeScale[17] = 7200.0;      // 2 hr
+		TimeScale[18] = 10800.0;     // 3 hr
+		TimeScale[19] = 21600.0;     // 6 hr
+		TimeScale[20] = 43200.0;     // 12 hr
+		setMinValue( -41 );
+		setMaxValue(  41 );
+		i = 20;
+	} else {
+		setMinValue( -21 );
+		setMaxValue(  21 );
+	}
+	TimeScale[i+1] = SECS_PER_DAY;     // 1 day
+	TimeScale[i+2] = 2.*SECS_PER_DAY;  // 2 days
+	TimeScale[i+3] = 3.*SECS_PER_DAY;  // 3 days
+	TimeScale[i+4] = 5.*SECS_PER_DAY;  // 5 days
+	TimeScale[i+5] = 7.*SECS_PER_DAY;  // 1 week
+	TimeScale[i+6] = 14.*SECS_PER_DAY; //2 weeks
+	TimeScale[i+7] = 21.*SECS_PER_DAY; //3 weeks    
 //Months aren't a simple measurement of time; I'll just use fractions of a year
-	TimeScale[28] = SIDEREAL_YEAR/12.0; // 1 month
-	TimeScale[29] = SIDEREAL_YEAR/6.0;  // 2 months
-	TimeScale[30] = 0.25*SIDEREAL_YEAR; // 3 months
-	TimeScale[31] = SIDEREAL_YEAR/3.0;  // 4 months
-	TimeScale[32] = 0.5*SIDEREAL_YEAR;  // 6 months
-	TimeScale[33] = 0.75*SIDEREAL_YEAR; // 9 months
-	TimeScale[34] = SIDEREAL_YEAR;       // 1 year
-	TimeScale[35] = 2.0*SIDEREAL_YEAR;   // 2 years
-	TimeScale[36] = 3.0*SIDEREAL_YEAR;   // 3 years
-	TimeScale[37] = 5.0*SIDEREAL_YEAR;   // 5 years
-	TimeScale[38] = 10.0*SIDEREAL_YEAR;  // 10 years
-	TimeScale[39] = 25.0*SIDEREAL_YEAR;  // 25 years
-	TimeScale[40] = 50.0*SIDEREAL_YEAR;  // 50 years
-	TimeScale[41] = 100.0*SIDEREAL_YEAR; // 100 years
+	TimeScale[i+8] = SIDEREAL_YEAR/12.0; // 1 month
+	TimeScale[i+9] = SIDEREAL_YEAR/6.0;  // 2 months
+	TimeScale[i+10] = 0.25*SIDEREAL_YEAR; // 3 months
+	TimeScale[i+11] = SIDEREAL_YEAR/3.0;  // 4 months
+	TimeScale[i+12] = 0.5*SIDEREAL_YEAR;  // 6 months
+	TimeScale[i+13] = 0.75*SIDEREAL_YEAR; // 9 months
+	TimeScale[i+14] = SIDEREAL_YEAR;       // 1 year
+	TimeScale[i+15] = 2.0*SIDEREAL_YEAR;   // 2 years
+	TimeScale[i+16] = 3.0*SIDEREAL_YEAR;   // 3 years
+	TimeScale[i+17] = 5.0*SIDEREAL_YEAR;   // 5 years
+	TimeScale[i+18] = 10.0*SIDEREAL_YEAR;  // 10 years
+	TimeScale[i+19] = 25.0*SIDEREAL_YEAR;  // 25 years
+	TimeScale[i+20] = 50.0*SIDEREAL_YEAR;  // 50 years
+	TimeScale[i+21] = 100.0*SIDEREAL_YEAR; // 100 years
 
-	TimeString.append( "0 " + i18n( "seconds", "secs" ));
-	TimeString.append( "0.1 " + i18n( "seconds", "secs" ));
-	TimeString.append( "0.25 " + i18n( "seconds", "secs" ));
-	TimeString.append( "0.5 " + i18n( "seconds", "secs" ));
-	TimeString.append( "1 " + i18n( "second", "sec" ));
-	TimeString.append( "2 " + i18n( "seconds", "secs" ));
-	TimeString.append( "5 " + i18n( "seconds", "secs" ));
-	TimeString.append( "10 " + i18n( "seconds", "secs" ));
-	TimeString.append( "20 " + i18n( "seconds", "secs" ));
-	TimeString.append( "30 " + i18n( "seconds", "secs" ));
-	TimeString.append( "1 " + i18n( "minute", "min" ));
-	TimeString.append( "2 " + i18n( "minutes", "mins" ));
-	TimeString.append( "5 " + i18n( "minutes", "mins" ));
-	TimeString.append( "10 " + i18n( "minutes", "mins" ));
-	TimeString.append( "15 " + i18n( "minutes", "mins" ));
-	TimeString.append( "30 " + i18n( "minutes", "mins" ));
-	TimeString.append( "1 " + i18n( "hour" ));
-	TimeString.append( "2 " + i18n( "hours", "hrs" ));
-	TimeString.append( "3 " + i18n( "hours", "hrs" ));
-	TimeString.append( "6 " + i18n( "hours", "hrs" ));
-	TimeString.append( "12 " + i18n( "hours", "hrs" ));
+	TimeString.clear();
+	if ( ! daysOnly() ) {
+		TimeString.append( "0 " + i18n( "seconds", "secs" ));
+		TimeString.append( "0.1 " + i18n( "seconds", "secs" ));
+		TimeString.append( "0.25 " + i18n( "seconds", "secs" ));
+		TimeString.append( "0.5 " + i18n( "seconds", "secs" ));
+		TimeString.append( "1 " + i18n( "second", "sec" ));
+		TimeString.append( "2 " + i18n( "seconds", "secs" ));
+		TimeString.append( "5 " + i18n( "seconds", "secs" ));
+		TimeString.append( "10 " + i18n( "seconds", "secs" ));
+		TimeString.append( "20 " + i18n( "seconds", "secs" ));
+		TimeString.append( "30 " + i18n( "seconds", "secs" ));
+		TimeString.append( "1 " + i18n( "minute", "min" ));
+		TimeString.append( "2 " + i18n( "minutes", "mins" ));
+		TimeString.append( "5 " + i18n( "minutes", "mins" ));
+		TimeString.append( "10 " + i18n( "minutes", "mins" ));
+		TimeString.append( "15 " + i18n( "minutes", "mins" ));
+		TimeString.append( "30 " + i18n( "minutes", "mins" ));
+		TimeString.append( "1 " + i18n( "hour" ));
+		TimeString.append( "2 " + i18n( "hours", "hrs" ));
+		TimeString.append( "3 " + i18n( "hours", "hrs" ));
+		TimeString.append( "6 " + i18n( "hours", "hrs" ));
+		TimeString.append( "12 " + i18n( "hours", "hrs" ));
+	} else {
+		TimeString.append( "0 " + i18n( "days" ));
+	}
 	TimeString.append( "1 " + i18n( "day" ));
 	TimeString.append( "2 " + i18n( "days" ));
 	TimeString.append( "3 " + i18n( "days" ));
@@ -130,9 +163,6 @@ TimeSpinBox::TimeSpinBox( QWidget *parent, const char *name )
 	TimeString.append( "25 " + i18n( "years", "yrs" ));
 	TimeString.append( "50 " + i18n( "years", "yrs" ));
 	TimeString.append( "100 " + i18n( "years", "yrs" ));
-
-	connect( this, SIGNAL( valueChanged( int ) ), this, SLOT( reportChange() ) );
-	updateDisplay();
 }
 
 int TimeSpinBox::mapTextToValue( bool *ok ) {
