@@ -21,24 +21,40 @@
 #include <qspinbox.h>
 #include <qstringlist.h>
 
-/**Custom spinbox to handle selection of timestep values with variable units.
+/**@class TimeSpinBox 
+	*Custom spinbox to handle selection of timestep values with variable units.
+	*@note this should only be used internally, embedded in a TimeStepBox widget.
 	*@author Jason Harris
-	*@version 0.9
-  */
+	*@version 1.0
+	*/
 
 class TimeSpinBox : public QSpinBox  {
 Q_OBJECT
 public:
 /**Constructor */
-	TimeSpinBox( QWidget *parent, const char* name=0 );
+	TimeSpinBox( QWidget *parent, const char* name=0, bool daysOnly = false );
 /**Destructor (empty)*/
 	~TimeSpinBox() {};
 
+	/**Convert the internal value to a display string.
+		*@note reimplemented from QSpinBox
+		*@p value the internal value to convert to a display string
+		*@return the display string
+		*/
 	virtual QString mapValueToText( int value );
+	
+	/**Convert the displayed string to an internal value.
+		*@note reimplemented from QSpinBox
+		*@p ok bool pointer set to TRUE if conversion was successful
+		*@return internal value converted from displayed text
+		*/
 	virtual int mapTextToValue( bool *ok);
 
-	/**@returns the current TimeStep setting */
-	float timeScale();
+	/**@return the current TimeStep setting */
+	float timeScale() const;
+
+	void setDaysOnly( bool daysonly );
+	bool daysOnly() const { return DaysOnly; }
 
 signals:
 	void scaleChanged( float s );
@@ -50,6 +66,7 @@ protected slots:
 	void reportChange();
 
 private:
+	bool DaysOnly;
 	float TimeScale[42];
 	QStringList TimeString;
 };
