@@ -21,6 +21,8 @@
 #include <qsignalmapper.h>
 #include <qcheckbox.h>
 #include <qlabel.h>
+#include <qgroupbox.h>
+//#include <qimevent.h>
 
 // KDE Header
 #include <klocale.h>
@@ -43,14 +45,16 @@
 #include "ktouchstatus.h"
 #include "ktouchslideline.h"
 #include "ktouchkeyboardwidget.h"
-#include "ktouchkeyboardeditor.h"
+#include "ktouchcoloreditor.h"
 #include "ktouchtrainer.h"
 #include "ktouchstatistics.h"
 #include "ktouchprefgenerallayout.h"
 #include "ktouchpreftraininglayout.h"
 #include "ktouchprefkeyboardlayout.h"
 #include "ktouchprefcolorslayout.h"
+#include "ktouchutils.h"
 #include "prefs.h"
+#include "ktouchcolorscheme.h"
 
 KTouch * KTouchPtr = NULL;
 
@@ -98,7 +102,9 @@ KTouch::KTouch()
 		// Load statistics data from statistics-file
 		
 	    // Reload the last used training file.
-		if (!m_lecture.loadXML(this, Prefs::currentLectureFile() )) {
+		if (Prefs::currentLectureFile().isNull() ||
+		    !m_lecture.loadXML(this, Prefs::currentLectureFile() ))
+		{
 			Prefs::setCurrentLectureFile(QString::null);
 			m_defaultLectureAction->setCurrentItem(-1);
 		}
@@ -128,10 +134,14 @@ KTouch::~KTouch() {
 // ----------------------------------------------------------------------------
 
 KTouchLectureStats& KTouch::getCurrentLectureStats() {
-	KTouchLectureStats& stat = m_stats.m_lectureStats[Prefs::currentLectureFile()];
+//	kdDebug() << "[KTouch::getCurrentLectureStats]  " << endl;
+	KURL lectureURL = Prefs::currentLectureFile();
+	if (lectureURL.url().isEmpty())  lectureURL = "default";
+//	kdDebug() << "  lectureURL = '" << lectureURL << "'" << endl;
+	KTouchLectureStats& stat = m_stats.m_lectureStats[lectureURL];
 	// add additional info to the statistics
 	if (stat.m_lectureURL.isEmpty())
-		stat.m_lectureURL = Prefs::currentLectureFile();
+		stat.m_lectureURL = lectureURL;
 	if (stat.m_lectureTitle.isEmpty())
 		stat.m_lectureTitle = m_lecture.m_title;
 	return stat;
@@ -150,19 +160,40 @@ void KTouch::clearStatistics() {
 void KTouch::applyPreferences() {
 	// This applies a new color scheme for the keyboard and also updates all other
 	// changes for the keyboard widget
-	changeColor(Prefs::colorScheme());
+	changeColor(Prefs::currentColorScheme());
 	m_slideLineWidget->applyPreferences();
+	m_statusWidget->applyPreferences();
 }
 // ----------------------------------------------------------------------------
 
 void KTouch::keyPressEvent(QKeyEvent *keyEvent) {
     if (keyEvent->text().isEmpty()) return;
+
     // if we the training session is paused, continue training now
     if (m_trainer->m_trainingPaused)  {
 		m_trainingPause->setEnabled(true);
 		m_trainer->continueTraining();
 	}
+	if (keyEvent->text().length() > 1) {
+		kdDebug() << "[KTouch::keyPressEvent]  text = '" << keyEvent->text() << "'" << endl;
+	}
     QChar key = keyEvent->text().at(0); // get first unicode character
+	// HACK : manually filter out known dead keys
+//	bool has_dead_key = true;
+	switch (key.unicode()) {
+		case 94   : m_lastDeadKey = QChar(uint(94)); break;
+		case 176  : m_lastDeadKey = QChar(uint(176)); break;
+		case 180  : m_lastDeadKey = QChar(uint(180)); break;
+		case 96   : m_lastDeadKey = QChar(uint(96)); break;
+		case 126  : m_lastDeadKey = QChar(uint(126)); break;
+		default   : m_lastDeadKey = QChar(uint(0));
+	}
+	if (m_lastDeadKey != QChar(uint(0)) && key == m_lastDeadKey) {
+//		kdDebug() << "Got dead key = " << m_lastDeadKey << endl;
+    	//keyEvent->accept();
+//		return;
+	}
+
     if (key.isPrint())
         m_trainer->keyPressed(key);
     else if (key==QChar(8))
@@ -175,6 +206,7 @@ void KTouch::keyPressEvent(QKeyEvent *keyEvent) {
 }
 // ----------------------------------------------------------------------------
 
+
 void KTouch::configOverrideLectureFontToggled(bool on) {
 	if (on) {
 		m_pageGeneral->fontTextLabel->setEnabled(true);
@@ -215,6 +247,7 @@ void KTouch::configAutoLevelChangeToggled(bool on) {
 		m_pageTraining->kcfg_UpCorrectLimit->setEnabled(true);
 		m_pageTraining->kcfg_DownSpeedLimit->setEnabled(true);
 		m_pageTraining->kcfg_DownCorrectLimit->setEnabled(true);
+		m_pageTraining->kcfg_DisableManualLevelChange->setEnabled(true);
 	}
 	else {
 		m_pageTraining->l1->setEnabled(false);
@@ -231,10 +264,16 @@ void KTouch::configAutoLevelChangeToggled(bool on) {
 		m_pageTraining->kcfg_UpCorrectLimit->setEnabled(false);
 		m_pageTraining->kcfg_DownSpeedLimit->setEnabled(false);
 		m_pageTraining->kcfg_DownCorrectLimit->setEnabled(false);
+		m_pageTraining->kcfg_DisableManualLevelChange->setEnabled(false);
 	}	
 }
 // ----------------------------------------------------------------------------
 
+void KTouch::configCommonColorsToggled(bool on) {
+	m_pageColors->colorsGroup->setEnabled(on);
+}
+// ----------------------------------------------------------------------------
+
 // The action File->Open lecture...
 void KTouch::fileOpenLecture() {
 	trainingPause();
@@ -272,12 +311,52 @@ void KTouch::fileEditLecture() {
 }
 // ----------------------------------------------------------------------------
 
+// The action File->Edit colors...
+void KTouch::fileEditColors() {
+	trainingPause();
+	// Create a copy of the currently editable color schemes.
+	QValueList<KTouchColorScheme> tmp_list;
+	int default_schemes = 0;
+	for (QValueVector<KTouchColorScheme>::const_iterator it = KTouchColorScheme::m_colorSchemes.constBegin();
+		it != KTouchColorScheme::m_colorSchemes.constEnd(); ++it)
+	{
+		if (!it->m_default) 	tmp_list.append(*it);
+		else 					++default_schemes;
+	}
+	
+	KTouchColorEditor dlg(this);		// Create editor
+	// start editor
+	int selected;
+	dlg.startEditor( tmp_list, Prefs::currentColorScheme() - default_schemes, selected);
+	KTouchColorScheme::createDefaults();
+	for (QValueList<KTouchColorScheme>::const_iterator it = tmp_list.constBegin();
+		it != tmp_list.constEnd(); ++it)
+	{
+		KTouchColorScheme::m_colorSchemes.append(*it);
+	}
+	// update the quick select menu
+    QStringList schemes_list;
+    for (unsigned int i=0; i<KTouchColorScheme::m_colorSchemes.count(); ++i)
+		schemes_list.append(KTouchColorScheme::m_colorSchemes[i].m_name);
+    m_keyboardColorAction->setItems(schemes_list);
+	int index = selected + default_schemes;
+	if (index >=0 && index < static_cast<int>(KTouchColorScheme::m_colorSchemes.count())) {
+		Prefs::setCurrentColorScheme(index);
+	}
+	else {
+		Prefs::setCurrentColorScheme(1); // fall back on default in case active was deleted
+	}
+   	m_keyboardColorAction->setCurrentItem(Prefs::currentColorScheme());
+	applyPreferences();
+}
+// ----------------------------------------------------------------------------
+
 // The action File->Edit keyboard...
 void KTouch::fileEditKeyboard() {
 	trainingPause();
 	// Create and execute editor
-    KTouchKeyboardEditor dlg(this);
-    dlg.startEditor( Prefs::currentKeyboardFile() );
+//    KTouchKeyboardEditor dlg(this);
+//    dlg.startEditor( Prefs::currentKeyboardFile() );
 	// Reload lecture in case it was modified
 	//m_keyboard.loadXML(this, Prefs::currentKeyboardFile() );
 	//updateFontFromLecture();
@@ -342,7 +421,7 @@ void KTouch::optionsPreferences() {
 	dialog->addPage(m_pageTraining, i18n("Training Options"), "kalarm");
 	m_pageKeyboard = new KTouchPrefKeyboardLayout(0, "Keyboard");
 	dialog->addPage(m_pageKeyboard, i18n("Keyboard Settings"), "keyboard_layout");
-	KTouchPrefColorsLayout *m_pageColors = new KTouchPrefColorsLayout(0, "Colors"); 
+	m_pageColors = new KTouchPrefColorsLayout(0, "Colors"); 
 	dialog->addPage(m_pageColors, i18n("Color Settings"), "package_graphics");
 	connect(dialog, SIGNAL(settingsChanged()), this, SLOT(applyPreferences()));
 	// TODO : Connect some other buttons/check boxes of the dialog
@@ -352,10 +431,13 @@ void KTouch::optionsPreferences() {
 		this, SLOT(configOverrideKeyboardFontToggled(bool)));
 	connect(m_pageTraining->kcfg_AutoLevelChange, SIGNAL(toggled(bool)), 
 		this, SLOT(configAutoLevelChangeToggled(bool)));
+	connect(m_pageColors->kcfg_CommonTypingLineColors, SIGNAL(toggled(bool)),
+		this, SLOT(configCommonColorsToggled(bool)));
 	// call the functions to enable/disable controls depending on settings
 	configOverrideLectureFontToggled(Prefs::overrideLectureFont());
 	configOverrideKeyboardFontToggled(Prefs::overrideKeyboardFont());
 	configAutoLevelChangeToggled(Prefs::autoLevelChange());
+	configCommonColorsToggled(Prefs::commonTypingLineColors());
 	dialog->show();
 }
 // ----------------------------------------------------------------------------
@@ -378,17 +460,18 @@ void KTouch::changeStatusbarStats(unsigned int level_correct, unsigned int level
 void KTouch::changeKeyboard(int num) {
     if (static_cast<unsigned int>(num)>=m_keyboardFiles.count()) return;
     Prefs::setCurrentKeyboardFile( m_keyboardFiles[num] );
-	//kdDebug() << "[KTouch::changeKeyboard]  new keyboard layout = " << Prefs::currentKeyboardFile() << endl;
+//	kdDebug() << "[KTouch::changeKeyboard]  new keyboard layout = " << Prefs::currentKeyboardFile() << endl;
     m_keyboardLayoutAction->setCurrentItem(num);
 	// call Apply-Preferenzes in "noisy"-mode, pop up an error if the chosen layout file is corrupt
-    m_keyboardWidget->applyPreferences(this, false);  
+    m_keyboardWidget->applyPreferences(this, false);
 }
 // ----------------------------------------------------------------------------
 
 void KTouch::changeColor(int num) {
-    if (static_cast<unsigned int>(num)>=m_colorSchemes.count()) return;
-    Prefs::setColorScheme(num);
+    if (static_cast<unsigned int>(num)>=KTouchColorScheme::m_colorSchemes.count()) return;
+    Prefs::setCurrentColorScheme(num);
     m_keyboardWidget->applyPreferences(this, false);
+	m_slideLineWidget->applyPreferences();
 }
 // ----------------------------------------------------------------------------
 
@@ -430,6 +513,8 @@ bool KTouch::queryExit() {
 	KURL stat_file = KGlobal::dirs()->saveLocation("data","ktouch", true) + "statistics.xml";
 	//kdDebug() << "[KTouch::queryExit]  Writing statistics to file: '" << stat_file << "'" << endl;
 	m_stats.write(this, stat_file);
+	KURL color_file = KGlobal::dirs()->saveLocation("data","ktouch", true) + "color_schemes.xml";
+	KTouchColorScheme::writeList(this, color_file);
     return true;
 }
 // ----------------------------------------------------------------------------
@@ -489,8 +574,8 @@ void KTouch::saveProperties(KConfig *config) {
     // next logon.
 
 	// TODO : Session management rewrite
-    config->setGroup("TrainingState");
 /*
+    config->setGroup("TrainingState");
     // first write the current lecture URL and the training position
     config->writePathEntry("Lecture", m_currentLectureURL.url());
     config->writeEntry("Level", m_trainer->m_level);
@@ -518,25 +603,44 @@ void KTouch::init() {
 	//kdDebug() << "[KTouch::init]  " << m_keyboardFiles.count() << " keyboard layouts available" << endl;
 	//kdDebug() << "[KTouch::init]  " << m_examinationFiles.count() << " examination files available" << endl;
 
-	/// \todo look up a default english lecture in the m_lectureFiles string list
-	QString default_lecture;
-	if (m_lectureFiles.count() > 0)  default_lecture = m_lectureFiles[0];
-	if (Prefs::currentLectureFile() == "default")
+	if (Prefs::currentLectureFile() == "default") {
+		Prefs::setCurrentLectureFile(QString::null);
+//		/// \todo look up a lecture in the language of the KDE locale
+/*		QString default_lecture = "default";
+		if (m_lectureFiles.count() > 0)  default_lecture = m_lectureFiles[0];
 		Prefs::setCurrentLectureFile( default_lecture );
+*/
+	}
 
-    // read keyboard layouts
-	QString default_keyboard = "number.keyboard";
-	// look up the default english keyboard file in the m_keyboardFiles string list
-	QStringList::iterator it = m_keyboardFiles.begin();
-	while (it != m_keyboardFiles.end()   &&   (*it).find("en.keyboard") == -1)  ++it;
-	if (it != m_keyboardFiles.end())   default_keyboard = *it;
     // if keyboard layout (loaded by Prefs is not available (e.g. the 
-	// layout file has been deleted) switch to default keyboard
-    if (m_keyboardFiles.contains(Prefs::currentKeyboardFile() )==0)
-        Prefs::setCurrentKeyboardFile ( default_keyboard );
+    // layout file has been deleted) switch to default keyboard
+    if (m_keyboardFiles.contains(Prefs::currentKeyboardFile() )==0) {
+        QString default_keyboard;
+        // determine locale
+        QString lang = KGlobal::locale()->language();
+        QString fname = lang + ".keyboard";
+        // try to find keyboard with current locale
+        QStringList::const_iterator it = m_keyboardFiles.constBegin();
+        while (it != m_keyboardFiles.constEnd()   &&   (*it).find(fname) == -1)  ++it;
+        if (it == m_keyboardFiles.constEnd()) {
+            fname = lang.left(2) + ".keyboard";
+            // try to find more general version 
+            it = m_keyboardFiles.constBegin();
+            while (it != m_keyboardFiles.constEnd()   &&   (*it).find(fname) == -1)  ++it;
+        }
 
-	// create some default colour schemes
-	createDefaultColorSchemes();
+        if (it != m_keyboardFiles.constEnd())
+            default_keyboard = *it;
+        else 
+            default_keyboard = "number.keyboard";
+        Prefs::setCurrentKeyboardFile ( default_keyboard );
+    }
+
+    // create some default colour schemes
+    KTouchColorScheme::createDefaults();
+    // read additional color schemes
+	KURL color_file = KGlobal::dirs()->findResource("data", "ktouch/color_schemes.xml");
+	KTouchColorScheme::readList(this, color_file);
 }
 // ----------------------------------------------------------------------------
 
@@ -571,10 +675,12 @@ void KTouch::initTrainingSession() {
 // Creates the (standard) actions and entries in the menu.
 void KTouch::setupActions() {
 	// *** File menu ***
-    new KAction(i18n("&Open Lecture..."), "open_lecture", 0, 
+    new KAction(i18n("&Open lecture..."), "open_lecture", 0,
 		this, SLOT(fileOpenLecture()), actionCollection(), "file_openlecture");
-    new KAction(i18n("&Edit Lecture..."), "edit_lecture", 0, 
+    new KAction(i18n("&Edit lecture..."), "edit_lecture", 0,
 		this, SLOT(fileEditLecture()), actionCollection(), "file_editlecture");
+    new KAction(i18n("&Edit color scheme..."), "edit_colors", 0,
+		this, SLOT(fileEditColors()), actionCollection(), "file_editcolors");
 //    new KAction(i18n("&Edit Keyboard..."), "edit_keyboard", 0, 
 //		this, SLOT(fileEditKeyboard()), actionCollection(), "file_editkeyboard");
     KStdAction::quit(this, SLOT(fileQuit()), actionCollection());
@@ -589,6 +695,7 @@ void KTouch::setupActions() {
  
     // Setup menu entries for the training lectures
     m_defaultLectureAction = new KSelectAction(i18n("Default &Lectures"), 0, this, 0, actionCollection(), "default_lectures");
+	m_defaultLectureAction->setMenuAccelsEnabled(false);
     m_defaultLectureAction->setItems(m_lectureTitles);
     m_defaultLectureAction->setCurrentItem(0);  
     connect (m_defaultLectureAction, SIGNAL(activated(int)), this, SLOT(changeLecture(int)));
@@ -597,16 +704,20 @@ void KTouch::setupActions() {
     KStdAction::preferences(this, SLOT(optionsPreferences()), actionCollection());
     // Setup menu entries for keyboard layouts    
     m_keyboardLayoutAction= new KSelectAction(i18n("&Keyboard Layouts"), 0, this, 0, actionCollection(), "keyboard_layouts");
-    m_keyboardLayoutAction->setItems(m_keyboardFiles);
+	m_keyboardLayoutAction->setMenuAccelsEnabled(false);
+    m_keyboardLayoutAction->setItems(m_keyboardTitles);
     connect (m_keyboardLayoutAction, SIGNAL(activated(int)), this, SLOT(changeKeyboard(int)));
 
 	// Setup menu entries for colour schemes
-	m_keyboardColorAction = new KSelectAction(i18n("Keyboards &Color Schemes"), 0, this, 0, actionCollection(), "keyboard_schemes");
+	m_keyboardColorAction = new KSelectAction(i18n("&Color Schemes"), 0, this, 0, actionCollection(), "keyboard_schemes");
     QStringList schemes_list;
-    for (unsigned int i=0; i<m_colorSchemes.count(); ++i)
-		schemes_list.append(m_colorSchemes[i].m_name);
+    for (unsigned int i=0; i<KTouchColorScheme::m_colorSchemes.count(); ++i)
+		schemes_list.append(KTouchColorScheme::m_colorSchemes[i].m_name);
+	m_keyboardColorAction->setMenuAccelsEnabled(false);
     m_keyboardColorAction->setItems(schemes_list);
-    m_keyboardColorAction->setCurrentItem(Prefs::colorScheme());  
+	if (static_cast<unsigned int>(Prefs::currentColorScheme()) >=  schemes_list.count())
+		Prefs::setCurrentColorScheme(1);
+   	m_keyboardColorAction->setCurrentItem(Prefs::currentColorScheme());
     connect (m_keyboardColorAction, SIGNAL(activated(int)), this, SLOT(changeColor(int)));
 }
 // ----------------------------------------------------------------------------
@@ -620,7 +731,7 @@ void KTouch::updateFontFromLecture() {
 		// TODO : if multiple font suggestions are given, try one after another until a
 		// suggested font is found
 		if (f.fromString(m_lecture.m_fontSuggestions))	m_slideLineWidget->setFont(f);
-		else if (f.fromString("Courier 10 Pitch")) 		m_slideLineWidget->setFont(f);
+		else if (f.fromString("Monospace")) 		m_slideLineWidget->setFont(f);
 	}
 }
 // ----------------------------------------------------------------------------
@@ -632,14 +743,42 @@ void KTouch::updateFileLists() {
 	
     // first search for all installed keyboard files
 	// TODO : search in i18n() directories
-    QStringList keyboardFiles = dirs->findAllResources("data","ktouch/*.keyboard");
-	// TODO : extract titles from keyboard files and store them in the m_keyboardTitles string list
-	m_keyboardFiles = keyboardFiles;
+    m_keyboardFiles = dirs->findAllResources("data","ktouch/*.keyboard");
 
     // remove the number layout, since this is the necessary default layout and will be
     // added anyway
     QStringList::iterator it = m_keyboardFiles.find("number.keyboard");
-	if (it!=m_keyboardFiles.end())		m_keyboardFiles.remove(it);
+    if (it!=m_keyboardFiles.end())      m_keyboardFiles.remove(it);
+
+    m_keyboardTitles.clear();
+    for (QStringList::const_iterator cit = m_keyboardFiles.constBegin();
+        cit != m_keyboardFiles.constEnd(); ++cit)
+    {
+        // extract titles from keyboard files and store them in the
+        // m_keyboardTitles string list
+
+        // get the filename alone
+        QString fname = KURL(*cit).fileName();
+        // get the filename without the .keyboard
+        fname.truncate(fname.length() - 9);
+        // get everything in front of the first .
+        QString lang_iso = fname.section('.',0,0);
+        // get language description of file names
+        QString lang_name = KGlobal::locale()->twoAlphaToLanguageName(lang_iso);
+//        kdDebug() << fname << " | " << lang_iso << " | " << lang_name << endl;
+        if (lang_name.isEmpty())
+            lang_name = KGlobal::locale()->twoAlphaToCountryName(lang_iso);
+        if (!lang_name.isEmpty())
+            lang_name += " (" + fname + ")";
+        else
+            lang_name = fname;
+        m_keyboardTitles.append( lang_name );
+//        kdDebug() << m_keyboardTitles.back() << endl;
+    }
+
+    // now sort the files and titles accordingly
+    sort_lists(m_keyboardTitles, m_keyboardFiles);
+    // and add the number keypad to the front
     m_keyboardFiles.push_front("number.keyboard");
     m_keyboardTitles.push_front(i18n("Keypad/Number block"));
 
@@ -665,6 +804,7 @@ void KTouch::updateFileLists() {
 					m_lectureTitles.push_back(l.m_title);
 			}
         }
+        sort_lists(m_lectureTitles, m_lectureFiles);
     }
 
 	// Now find predefined files with colour schemes
@@ -673,68 +813,6 @@ void KTouch::updateFileLists() {
 }
 // ----------------------------------------------------------------------------
 
-void KTouch::createDefaultColorSchemes() {
-    KTouchColorScheme color;
-
-    color.m_name = i18n("Black && White");
-    color.m_frame = Qt::black;
-    for (int i=0; i<8; ++i)
-        color.m_background[i] = Qt::white;
-    color.m_text = Qt::black;
-    color.m_backgroundH = Qt::black;
-    color.m_textH = Qt::white;
-    color.m_cBackground = Qt::gray;
-    color.m_cText = Qt::black;
-    color.m_cBackgroundH = Qt::white;
-    color.m_cTextH = Qt::black;
-    m_colorSchemes.push_back(color);
-
-    color.m_name = i18n("Classic");
-    color.m_frame = Qt::black;
-    color.m_background[0] = QColor(255,238,  7);     color.m_background[4] = QColor(247,138,247);
-    color.m_background[1] = QColor( 14,164,239);     color.m_background[5] = QColor(158,255,155);
-    color.m_background[2] = QColor(158,255,155);     color.m_background[6] = QColor( 14,164,239);
-    color.m_background[3] = QColor(252,138,138);     color.m_background[7] = QColor(255,238,  7);
-    color.m_text = Qt::black;
-    color.m_backgroundH = Qt::darkBlue;
-    color.m_textH = Qt::white;
-    color.m_cBackground = Qt::gray;
-    color.m_cText = Qt::black;
-    color.m_cBackgroundH = Qt::white;
-    color.m_cTextH = Qt::black;
-    m_colorSchemes.push_back(color);
-
-    color.m_name = i18n("Deep Blue");
-    color.m_frame = QColor(220,220,220);
-    color.m_background[0] = QColor(  0, 39, 80);     color.m_background[4] = QColor( 24, 19, 72);
-    color.m_background[1] = QColor( 39, 59,127);     color.m_background[5] = QColor(  8, 44,124);
-    color.m_background[2] = QColor(  4, 39, 53);     color.m_background[6] = QColor( 10, 82,158);
-    color.m_background[3] = QColor( 40, 32,121);     color.m_background[7] = QColor( 43, 60,124);
-    color.m_text = Qt::white;
-    color.m_backgroundH = QColor(125,180,255);
-    color.m_textH = Qt::darkBlue;
-    color.m_cBackground = Qt::black;
-    color.m_cText = Qt::white;
-    color.m_cBackgroundH = QColor(111,121,73);
-    color.m_cTextH = Qt::white;
-    m_colorSchemes.push_back(color);
-
-    color.m_name = i18n("Stripy");
-    color.m_frame = Qt::black;
-    for (int i=0; i<8; i=i+2)
-        color.m_background[i] = QColor( 39, 70, 127);
-	for (int i=1; i<8; i=i+2)
-        color.m_background[i] = Qt::darkGray;
-    color.m_text = Qt::black;
-    color.m_backgroundH = QColor( 39, 70, 227);
-    color.m_textH = Qt::white;
-    color.m_cBackground = Qt::gray;
-    color.m_cText = Qt::black;
-    color.m_cBackgroundH = QColor( 39, 70, 227);
-    color.m_cTextH = Qt::black;
-    m_colorSchemes.push_back(color);
-}
-// ----------------------------------------------------------------------------
 
 void KTouch::updateLectureActionCheck() {
 	int num = 0;
@@ -762,3 +840,31 @@ void KTouch::updateKeyboardActionCheck() {
 }
 // ----------------------------------------------------------------------------
 
+/*
+void KTouch::imStartEvent(QIMEvent *e) {
+	kdDebug() << "[KTouch::imStartEvent]  text = '" << e->text() << "'" << endl;
+  e->accept();
+}
+// ----------------------------------------------------------------------------
+
+void KTouch::imComposeEvent(QIMEvent *e) {
+	kdDebug() << "[KTouch::imComposeEvent]  text = '" << e->text() << "'" << endl;
+  e->accept();
+}
+// ----------------------------------------------------------------------------
+
+void KTouch::imEndEvent(QIMEvent *e) {
+	kdDebug() << "[KTouch::imEndEvent]  text = '" << e->text() << "'" << endl;
+  if (!e->text().isEmpty()) {
+    if (e->text() == "^") {
+      QKeyEvent *ev = new QKeyEvent (QEvent::KeyPress,
+                                    Qt::Key_AsciiCircum, '^', 0,
+                                    QString("^"));
+      keyPressEvent(ev);
+      delete ev;
+    }
+  }
+  e->accept();
+}
+// ----------------------------------------------------------------------------
+*/
