@@ -18,15 +18,16 @@
 #include "kstartuplogo.h"
 #include <kapplication.h>
 #include <kstandarddirs.h>
+#include <kglobalsettings.h>
 
 KStartupLogo::KStartupLogo(QWidget * parent, const char *name)
-: QWidget(parent,name,WStyle_Customize | WStyle_NoBorderEx  )
+: QWidget(parent,name,WStyle_Customize | WStyle_NoBorder  )
 { 	
   QPixmap pm;
   pm.load(locate("appdata", "pics/startuplogo.png"));
   setBackgroundPixmap(pm);
-  setGeometry(QApplication::desktop()->width()/2-pm.width()/2,
-              QApplication::desktop()->height()/2-pm.height()/2,
+  QRect desk = KGlobalSettings::splashScreenDesktopGeometry();
+  setGeometry(desk.center().x()-pm.width()/2, desk.center().y()-pm.height()/2,
               pm.width(),pm.height());
 }
 
