@@ -18,8 +18,6 @@
 #ifndef KVERBOSUSER_H
 #define KVERBOSUSER_H
 
-#include <qstring.h>
-#include <qvaluelist.h>
 #include "verbspanish.h"
 
 // Der maximale Wert fr den falsch bzw. richtig Zhler
