@@ -1,17 +1,14 @@
  /***************************************************************************
 
-    $Id: PhoneticEntryPage.cpp,v 1.3 2003/07/17 12:48:20 binner Exp $
-
               dialog page for characters from the phonetic alphabet
 
     -----------------------------------------------------------------------
 
-    begin                : Sun Dec 9 2001
+    begin          : Sun Dec 9 2001
 
-    copyright            : (C) 1999-2002 Ewald Arnold
-                           (C) 2001-2002 The KDE-EDU team
-
-    email                : kvoctrain@ewald-arnold.de
+    copyright      : (C) 2001-2002 Ewald Arnold <kvoctrain@ewald-arnold.de>
+                     (C) 2001-2002 The KDE-EDU team
+                     (C) 2005 Peter Hedlund <peter.hedlund@kdemail.net>
 
     -----------------------------------------------------------------------
 
@@ -30,7 +27,7 @@
 #include "PhoneticEntryPage.h"
 
 #include <qlayout.h>
-#include <qpushbutton.h>
+#include <qframe.h>
 #include <qgroupbox.h>
 #include <qtooltip.h>
 
@@ -178,12 +175,12 @@ void PhoneticButton::slotClicked()
 }
 
 
-PhoneticEntryPage::PhoneticEntryPage(const QFont &ipafont, QWidget *parent, const char *name)
-  : PhoneticEntryPageForm(parent, name, /*modal*/false)
+PhoneticEntryPage::PhoneticEntryPage(const QFont &ipafont, QWidget *parent, const char *name, bool modal)
+  : KDialogBase(Plain, i18n("Select Characters From Phonetic Alphabet"), Close, Close, parent, name, modal)
 {
   int num = sizeof(kv_unicode_ref) / sizeof(kv_unicode_ref[0]);
+  QFrame * phoneticbox = plainPage();
   QGridLayout *gbox = new QGridLayout(phoneticbox, KV_MAX_HORIZ, (num+KV_MAX_HORIZ-1)/KV_MAX_HORIZ, 1);
-  connect (b_close, SIGNAL(clicked()), SLOT(slotAbort()) );
 
   KV_Unicode_Ref *uni_ref = kv_unicode_ref;
   int vert = 0;
@@ -200,7 +197,7 @@ PhoneticEntryPage::PhoneticEntryPage(const QFont &ipafont, QWidget *parent, cons
     tip += i18n(uni_ref->audible);
     butt->setFont(ipafont);
     butt->setSizePolicy(QSizePolicy (QSizePolicy::Fixed, QSizePolicy::Fixed));
-    int sz = QMAX(14, 1.7*ipafont.pointSize());
+    int sz = QMAX(14, int(1.7*ipafont.pointSize()));
     butt->setMaximumSize(QSize (sz, sz));
     gbox->addWidget( butt, vert, horiz, AlignCenter );
     QToolTip::add (butt, tip);
@@ -215,12 +212,6 @@ PhoneticEntryPage::PhoneticEntryPage(const QFont &ipafont, QWidget *parent, cons
 }
 
 
-void PhoneticEntryPage::slotAbort()
-{
-  emit wantClose();
-}
-
-
 void PhoneticEntryPage::keyPressEvent( QKeyEvent *e )
 {
   if ((e->state() & (ControlButton | AltButton)) == 0) {
