@@ -1,17 +1,15 @@
 /***************************************************************************
 
-    $Id: kva_clip.cpp,v 1.11 2003/06/21 14:31:22 deller Exp $
-
                      clipboard part of kvoctrain
 
     -----------------------------------------------------------------------
 
     begin                : Thu Mar 11 20:50:53 MET 1999
-                                           
+
     copyright            : (C) 1999-2001 Ewald Arnold
                            (C) 2001 The KDE-EDU team
-                         
-    email                : kvoctrain@ewald-arnold.de                                    
+
+    email                : kvoctrain@ewald-arnold.de
 
     -----------------------------------------------------------------------
 
@@ -22,35 +20,21 @@
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   * 
+ *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
 
 #include "kvoctrain.h"
-#include <kvoctraincore.h>
 
 #include <qclipboard.h>
 
 #include <klineedit.h>
 #include <klocale.h>
-#include <kconfig.h>
 
+#include "prefs.h"
 #include <algorithm>
 using namespace std;
 
-void kvoctrainApp::clipboardChanged() {
-  QString s = QApplication::clipboard()->text();
-  edit_menu->setItemEnabled(ID_EDIT_PASTE,  !s.isEmpty());
-  edit_menu->setItemEnabled(ID_SEARCH_CLIP, !s.isEmpty());
-  toolBar()->setItemEnabled(ID_EDIT_PASTE,  !s.isEmpty());
-  toolBar()->setItemEnabled(ID_EDIT_PASTE,  !s.isEmpty());
-#if defined(_WS_X11_)
-//  disconnect(QApplication::clipboard(),SIGNAL(dataChanged()),
-//    this,SLOT(clipboardChanged()));
-#endif
-}
-
-
 void kvoctrainApp::slotSmartSearchClip()
 {
   QString s;
@@ -71,33 +55,22 @@ void kvoctrainApp::slotSmartSearchClip()
     searchLine->setFocus();
     searchLine->setText (searchstr);
   }
+  else
+    searchLine->setFocus();
 }
 
 
-void kvoctrainApp::aboutToShowEdit() {
-  QString s = QApplication::clipboard()->text();
-  edit_menu->setItemEnabled(ID_CLR_SEL,  hasSelection());
-  edit_menu->setItemEnabled(ID_SAVE_ROW,  hasSelection());
-  edit_menu->setItemEnabled(ID_EDIT_PASTE,  !s.isEmpty());
-  edit_menu->setItemEnabled(ID_SEARCH_CLIP, !s.isEmpty());
-  toolBar()->setItemEnabled(ID_SEARCH_CLIP, !s.isEmpty());
-  toolBar()->setItemEnabled(ID_EDIT_PASTE,  !s.isEmpty());
-}
-
-
-vector<int> kvoctrainApp::getCsvOrder(kvoctrainDoc *doc,
-                                      QStringList *lang_order)
+vector<int> kvoctrainApp::getCsvOrder(kvoctrainDoc *doc)
 {
   vector<int> csv_order;
+  QStringList lang_order = Prefs::pasteOrder();
 
-  KConfig *config = KApplication::kApplication()->config();
-  config->setGroup(CFG_GENERAL);
-  bool useCurrent = config->readBoolEntry(CFG_USECURRENT, false);
-
-  if (!useCurrent) {
-    if (lang_order && lang_order->count() != 0) {
-      for (int i = 0; i < (int) lang_order->count(); i++) {
-        int j = doc->findIdent((*lang_order)[i]);
+  if (!Prefs::useCurrent())
+  {
+    if (/*lang_order &&*/ lang_order.count() != 0) {
+      for (int i = 0; i < (int) lang_order.count(); i++)
+      {
+        int j = doc->findIdent((lang_order)[i]);
         if (j >= 0)
           csv_order.push_back (j);
         else
@@ -145,9 +118,9 @@ void kvoctrainApp::slotEditCopy()
   QString exp;
   QString s;
 
-  vector <int> csv_order = getCsvOrder(doc, &paste_order);
+  vector <int> csv_order = getCsvOrder(doc);
 
-  RowTable *table = view->getTable();
+  KVocTrainTable *table = view->getTable();
 
   for (int j = table->numRows()-1; j >= 0; j--) {
     if (table->isRowSelected(j))
@@ -160,8 +133,8 @@ void kvoctrainApp::slotEditCopy()
         if (!sep)
           sep = true;
         else
-          exp += separator;
-  
+          exp += Prefs::separator();
+
         if (csv_order[i] >= 0) {
           if (csv_order[i] == 0)
             exp += expr->getOriginal();
@@ -196,7 +169,7 @@ void kvoctrainApp::slotEditPaste()
   QString s;
   QString entries = QApplication::clipboard()->text();
 
-  vector <int> csv_order = getCsvOrder(doc, &paste_order);
+  vector <int> csv_order = getCsvOrder(doc);
 
   bool changed = false;
   QString num;
@@ -219,8 +192,8 @@ void kvoctrainApp::slotEditPaste()
     // similar block in kvd_csv.cpp::loadFromCsv()
 
     if (!s.stripWhiteSpace().isEmpty()) {
-      if (paste_order.count() != 0) {
-        kvoctrainExpr bucket (s, separator, act_lesson);
+      if (Prefs::pasteOrder().count() != 0) {
+        kvoctrainExpr bucket (s, Prefs::separator(), act_lesson);
         kvoctrainExpr expr;
         expr.setLesson(act_lesson);
         // now move columns according to paste-order
@@ -231,7 +204,7 @@ void kvoctrainApp::slotEditPaste()
               s = bucket.getOriginal();
             else
               s = bucket.getTranslation(i);
-  
+
             if (csv_order[i] == 0)
               expr.setOriginal(s);
             else
@@ -242,7 +215,7 @@ void kvoctrainApp::slotEditPaste()
         doc->appendEntry (&expr);
       }
       else {
-        kvoctrainExpr expr (s, separator, act_lesson);
+        kvoctrainExpr expr (s, Prefs::separator(), act_lesson);
         changed = true;
         doc->appendEntry (&expr);
       }
