@@ -1,16 +1,14 @@
 /***************************************************************************
 
-    $Id: QueryManager.cpp,v 1.15 2003/11/01 09:30:18 arnold Exp $
-
                              manage queries
 
     -----------------------------------------------------------------------
 
-    begin                : Sat Jul 11 20:50:53 MET 1999
+    begin          : Sat Jul 11 20:50:53 MET 1999
 
-    copyright            : (C) 1999-2001 Ewald Arnold
-                           (C) 2001 The KDE-EDU team
-    email                : kvoctrain@ewald-arnold.de
+    copyright      : (C) 1999-2001 Ewald Arnold <kvoctrain@ewald-arnold.de>
+                     (C) 2001 The KDE-EDU team
+                     (C) 2005 Peter Hedlund <peter.hedlund@kdemail.net>
 
     -----------------------------------------------------------------------
 
@@ -25,19 +23,17 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "QueryManager.h"
-#include "kvoctraincore.h"
-
 #include <klocale.h>
-#include <kapplication.h>
 #include <kconfig.h>
 
-#include "kvoctraindoc.h"
-
 #include <iostream>
 #include <vector>
 using namespace std;
 
+#include "QueryManager.h"
+#include "kvoctraincore.h"
+#include <prefs.h>
+
 vector<QString> QueryManager::userTypes;
 
 struct t_type_rel
@@ -93,19 +89,20 @@ static t_type_rel InternalTypeRelations [] =
 };
 
 
-QString QueryManager::getSubType (QString type)
+QString QueryManager::getSubType (const QString & type)
 {
   int i;
-  if ((i = type.find(QM_TYPE_DIV)) >= 0) {
-    type.remove(0, i+1);
-    return type;
+  QString t = type;
+  if ((i = t.find(QM_TYPE_DIV)) >= 0) {
+    t.remove(0, i+1);
+    return t;
   }
   else
     return QString::null;
 }
 
 
-QString QueryManager::getMainType (QString type)
+QString QueryManager::getMainType (const QString & type)
 {
   int i;
   if ((i = type.find(QM_TYPE_DIV)) >= 0)
@@ -115,136 +112,13 @@ QString QueryManager::getMainType (QString type)
 }
 
 
-QueryManager::QueryManager ()
+QueryManager::QueryManager()
 {
-  datecomp = DontCare;
-  badcomp = DontCare;
-  querycomp = DontCare;
-  gradecomp = DontCare;
-  typecomp = DontCare;
-  lessoncomp = DontCare;
-
-  dateitem = 0;
-  queryitem = 0;
-  baditem = 0;
-  typeitem = QString::null;
-  gradeitem = 0;
   lessonitems.clear();
 }
 
 
-void QueryManager::loadConfig (KConfig *config)
-{
-  datecomp = (CompType) config->readNumEntry(CFG_QM_DATE_COMP, DontCare);
-  badcomp = (CompType) config->readNumEntry(CFG_QM_BAD_COMP, DontCare);
-  querycomp = (CompType) config->readNumEntry(CFG_QM_QUERY_COMP, DontCare);
-  gradecomp = (CompType) config->readNumEntry(CFG_QM_GRADE_COMP, DontCare);
-  typecomp = (CompType) config->readNumEntry(CFG_QM_TYPE_COMP, DontCare);
-  lessoncomp = (CompType) config->readNumEntry(CFG_QM_LESSON_COMP, Current);
-
-  dateitem = (CompType) config->readNumEntry(CFG_QM_DATE_ITEM, 0);
-  baditem = (CompType) config->readNumEntry(CFG_QM_BAD_ITEM, 0);
-  queryitem = (CompType) config->readNumEntry(CFG_QM_QUERY_ITEM, 0);
-  gradeitem = (CompType) config->readNumEntry(CFG_QM_GRADE_ITEM, 0);
-  typeitem = config->readEntry(CFG_QM_TYPE_ITEM);
-//  setLessonItemStr (config->readEntry(CFG_QM_LESSON_ITEM));
-
-  blockItems.clear();
-  blockItems.push_back(config->readNumEntry(CFG_QM_BLOCK_ITEM"1", 1 *      60*60*24));
-  blockItems.push_back(config->readNumEntry(CFG_QM_BLOCK_ITEM"2", 2 *      60*60*24));
-  blockItems.push_back(config->readNumEntry(CFG_QM_BLOCK_ITEM"3", 4 *      60*60*24));
-  blockItems.push_back(config->readNumEntry(CFG_QM_BLOCK_ITEM"4", 1 *    7*60*60*24));
-  blockItems.push_back(config->readNumEntry(CFG_QM_BLOCK_ITEM"5", 2 *    7*60*60*24));
-  blockItems.push_back(config->readNumEntry(CFG_QM_BLOCK_ITEM"6", 1 *   30*60*60*24));
-  blockItems.push_back(config->readNumEntry(CFG_QM_BLOCK_ITEM"7", 2 *   30*60*60*24));
-
-  expireItems.clear();
-  expireItems.push_back(config->readNumEntry(CFG_QM_EXPIRE_ITEM"1", 2 *      60*60*24));
-  expireItems.push_back(config->readNumEntry(CFG_QM_EXPIRE_ITEM"2", 4 *      60*60*24));
-  expireItems.push_back(config->readNumEntry(CFG_QM_EXPIRE_ITEM"3", 1 *    7*60*60*24));
-  expireItems.push_back(config->readNumEntry(CFG_QM_EXPIRE_ITEM"4", 2 *    7*60*60*24));
-  expireItems.push_back(config->readNumEntry(CFG_QM_EXPIRE_ITEM"5", 1 *   30*60*60*24));
-  expireItems.push_back(config->readNumEntry(CFG_QM_EXPIRE_ITEM"6", 2 *   30*60*60*24));
-  expireItems.push_back(config->readNumEntry(CFG_QM_EXPIRE_ITEM"7", 4 *   30*60*60*24));
-}
-
-
-void QueryManager::saveConfig (KConfig *config)
-{
-  config->writeEntry(CFG_QM_DATE_COMP, (int) datecomp);
-  config->writeEntry(CFG_QM_BAD_COMP, (int) badcomp);
-  config->writeEntry(CFG_QM_QUERY_COMP, (int) querycomp);
-  config->writeEntry(CFG_QM_GRADE_COMP, (int) gradecomp);
-  config->writeEntry(CFG_QM_TYPE_COMP, (int) typecomp);
-  config->writeEntry(CFG_QM_LESSON_COMP, (int) lessoncomp);
-
-  config->writeEntry(CFG_QM_DATE_ITEM, (int) dateitem);
-  config->writeEntry(CFG_QM_BAD_ITEM, (int) baditem);
-  config->writeEntry(CFG_QM_QUERY_ITEM, (int) queryitem);
-  config->writeEntry(CFG_QM_GRADE_ITEM, (int) gradeitem);
-  config->writeEntry(CFG_QM_TYPE_ITEM, typeitem);
-//  config->writeEntry(CFG_QM_LESSON_ITEM, lessonItemStr());
-
-  QString s;
-  for (int i = KV_LEV1_GRADE;
-       i <= KV_MAX_GRADE && i <= (int) blockItems.size(); i++) {
-    s.setNum(i);
-    s.insert(0, CFG_QM_BLOCK_ITEM);
-    config->writeEntry(s, blockItems[i-1]);
-  }
-
-  for (int i = KV_LEV1_GRADE;
-       i <= KV_MAX_GRADE && i <= (int) expireItems.size(); i++) {
-    s.setNum(i);
-    s.insert(0, CFG_QM_EXPIRE_ITEM);
-    config->writeEntry(s, expireItems[i-1]);
-  }
-}
-
-
-int QueryManager::blockItem (int grade) const
-{
-   if (grade <= (int) blockItems.size() && grade > 0)
-    return  blockItems[grade-1];
-   else
-    return 0;
-}
-
-
-int QueryManager::expireItem (int grade) const
-{
-   if (grade <= (int) expireItems.size() && grade > 0)
-    return expireItems[grade-1];
-   else
-    return 0;
-}
-
-
-void QueryManager::setBlockItem (int item, int grade)
-{
-   if (grade > KV_MAX_GRADE || grade <= 0)
-     return;
-
-   for (int i = (int) blockItems.size(); i <= grade; i++)
-     blockItems.push_back(0);
-   blockItems[grade-1] = item;
-}
-
-
-void QueryManager::setExpireItem (int item, int grade)
-{
-   if (grade > KV_MAX_GRADE || grade <= 0)
-     return;
-
-   for (int i = (int) expireItems.size(); i <= grade; i++)
-     expireItems.push_back(0);
-   expireItems[grade-1] = item;
-}
-
-
-QuerySelection QueryManager::select(kvoctrainDoc *doc, int act_lesson,
-                                    int oindex, int tindex,
-                                    bool swap, bool block, bool expire)
+QuerySelection QueryManager::select(kvoctrainDoc *doc, int act_lesson, int oindex, int tindex)
 {
    QuerySelection random;
    random.resize(doc->numLessons()+1);
@@ -257,29 +131,31 @@ QuerySelection QueryManager::select(kvoctrainDoc *doc, int act_lesson,
    float f_ent_percent = doc->numEntries() / 100.0;
    emit doc->progressChanged(doc, 0);
 
+   //Note that Leitner style learning (altlearn) normally only uses 20
+   //entries, we just ignore that here
    for (int i = 0; i < doc->numEntries(); i++) {
      ent_no++;
      if (ent_percent != 0 && (ent_no % ent_percent) == 0 )
-       emit doc->progressChanged(doc, ent_no / f_ent_percent);
+       emit doc->progressChanged(doc, int (ent_no / f_ent_percent));
 
      kvoctrainExpr *expr = doc->getEntry(i);
+     unsigned int lessonno;
+     if (Prefs::altLearn())
+       lessonno = 0; //We only use a single array in Leitner style
+     else
+       lessonno = expr->getLesson();
+
      if (expr->isActive() ){
-       if (swap) {
-         if (  validate (expr, act_lesson,
-                       oindex, tindex,
-                       block, expire)
-             ||validate (expr, act_lesson,
-                       tindex, oindex,
-                       block, expire)) {
-           random[expr->getLesson()].push_back (QueryEntryRef(expr, i));
+       if (Prefs::swapDirection()) {
+         if (  validate (expr, act_lesson, oindex, tindex)
+             || validate (expr, act_lesson, tindex, oindex)) {
+           random[lessonno].push_back (QueryEntryRef(expr, i));
            expr->setInQuery(true);
          }
        }
        else {
-         if (validate (expr, act_lesson,
-                       oindex, tindex,
-                       block, expire)) {
-           random[expr->getLesson()].push_back (QueryEntryRef(expr, i));
+         if (validate (expr, act_lesson, oindex, tindex)) {
+           random[lessonno].push_back (QueryEntryRef(expr, i));
            expr->setInQuery(true);
          }
        }
@@ -294,29 +170,27 @@ QuerySelection QueryManager::select(kvoctrainDoc *doc, int act_lesson,
 }
 
 
-bool QueryManager::validate(kvoctrainExpr *expr, int act_lesson,
-                            int oindex, int tindex,
-                            bool block, bool expire)
+bool QueryManager::validate(kvoctrainExpr *expr, int act_lesson, int oindex, int tindex)
 {
    int index = tindex ? tindex : oindex;
    if ((compareExpiring(expr->getGrade(index, oindex != 0),
-                        expr->getQueryDate(index, oindex != 0), expire)
+                        expr->getQueryDate(index, oindex != 0), Prefs::expire())
         ||
 
         (
-            compareGrade (gradecomp, expr->getGrade(index, oindex != 0), gradeitem)
-         && compareQuery (querycomp, expr->getQueryCount(index, oindex != 0), queryitem)
-         && compareBad (badcomp, expr->getBadCount(index, oindex != 0), baditem)
-         && compareDate (datecomp, expr->getQueryDate(index, oindex != 0), dateitem)
+            compareGrade ((CompType) Prefs::compType(Prefs::EnumType::Grade), expr->getGrade(index, oindex != 0), Prefs::gradeItem())
+         && compareQuery ((CompType) Prefs::compType(Prefs::EnumType::Query), expr->getQueryCount(index, oindex != 0), Prefs::queryItem())
+         && compareBad ((CompType) Prefs::compType(Prefs::EnumType::Bad), expr->getBadCount(index, oindex != 0), Prefs::badItem())
+         && compareDate ((CompType) Prefs::compType(Prefs::EnumType::Date), expr->getQueryDate(index, oindex != 0), Prefs::dateItem())
 
          && compareBlocking(expr->getGrade(index, oindex != 0),
-                            expr->getQueryDate(index, oindex != 0), block)
+                            expr->getQueryDate(index, oindex != 0), Prefs::block())
         )
        )
 //     lesson + word type must ALWAYS match
 //     (and there must be a word on both sides)
-       && compareLesson (lessoncomp, expr->getLesson(), lessonitems, act_lesson)
-       && compareType (typecomp, expr->getType(index), typeitem)
+       && compareLesson ((CompType) Prefs::compType(Prefs::EnumType::Lesson), expr->getLesson(), lessonitems, act_lesson)
+       && compareType ((CompType) Prefs::compType(Prefs::EnumType::WordType), expr->getType(index), Prefs::typeItem())
        && !expr->getOriginal().stripWhiteSpace().isEmpty()
        && !expr->getTranslation(index).stripWhiteSpace().isEmpty()
       )
@@ -327,8 +201,7 @@ bool QueryManager::validate(kvoctrainExpr *expr, int act_lesson,
 }
 
 
-QuerySelection QueryManager::select(kvoctrainDoc *doc, int act_lesson,
-                                    int idx, QString type)
+QuerySelection QueryManager::select(kvoctrainDoc *doc, int act_lesson, int idx, QString type)
 {
    QuerySelection random;
    random.resize(doc->numLessons()+1);
@@ -344,7 +217,7 @@ QuerySelection QueryManager::select(kvoctrainDoc *doc, int act_lesson,
    for (int i = 0; i < doc->numEntries(); i++) {
      ent_no++;
      if (ent_percent != 0 && (ent_no % ent_percent) == 0 )
-       emit doc->progressChanged(doc, ent_no / f_ent_percent);
+       emit doc->progressChanged(doc, int (ent_no / f_ent_percent));
 
      kvoctrainExpr *expr = doc->getEntry(i);
      if (expr->isActive() && validate (expr, act_lesson, idx, type)) {
@@ -362,8 +235,7 @@ QuerySelection QueryManager::select(kvoctrainDoc *doc, int act_lesson,
 }
 
 
-bool QueryManager::validate(kvoctrainExpr *expr, int act_lesson,
-                            int idx, QString query_type)
+bool QueryManager::validate(kvoctrainExpr *expr, int act_lesson, int idx, QString query_type)
 {
    QString qtype;
    int pos = query_type.find (QM_TYPE_DIV);
@@ -395,7 +267,7 @@ bool QueryManager::validate(kvoctrainExpr *expr, int act_lesson,
    else
      return false;
 
-   if (compareLesson (lessoncomp, expr->getLesson(),
+   if (compareLesson ((CompType) Prefs::compType(Prefs::EnumType::Lesson), expr->getLesson(),
                       lessonitems, act_lesson)
        && type_ok) {
      return true;
@@ -406,8 +278,7 @@ bool QueryManager::validate(kvoctrainExpr *expr, int act_lesson,
 }
 
 
-QuerySelection QueryManager::select(kvoctrainDoc *doc, int act_lesson,
-                                    int idx, QueryType type)
+QuerySelection QueryManager::select(kvoctrainDoc *doc, int act_lesson, int idx, QueryType type)
 {
    QuerySelection random;
    random.resize(doc->numLessons()+1);
@@ -423,7 +294,7 @@ QuerySelection QueryManager::select(kvoctrainDoc *doc, int act_lesson,
    for (int i = 0; i < doc->numEntries(); i++) {
      ent_no++;
      if (ent_percent != 0 && (ent_no % ent_percent) == 0 )
-       emit doc->progressChanged(doc, ent_no / f_ent_percent);
+       emit doc->progressChanged(doc, int (ent_no / f_ent_percent));
 
      kvoctrainExpr *expr = doc->getEntry(i);
      if (expr->isActive() && validate (expr, act_lesson, idx, type)) {
@@ -441,8 +312,7 @@ QuerySelection QueryManager::select(kvoctrainDoc *doc, int act_lesson,
 }
 
 
-bool QueryManager::validate(kvoctrainExpr *expr, int act_lesson,
-                            int idx, QueryType query_type)
+bool QueryManager::validate(kvoctrainExpr *expr, int act_lesson, int idx, QueryType query_type)
 {
    bool type_ok = false;
    if (query_type == QT_Synonym) {
@@ -458,7 +328,7 @@ bool QueryManager::validate(kvoctrainExpr *expr, int act_lesson,
      type_ok = !expr->getExample(idx).stripWhiteSpace().isEmpty();
    }
 
-   if (compareLesson (lessoncomp, expr->getLesson(),
+   if (compareLesson ((CompType) Prefs::compType(Prefs::EnumType::Lesson), expr->getLesson(),
                       lessonitems, act_lesson)
        && type_ok) {
      return true;
@@ -469,11 +339,12 @@ bool QueryManager::validate(kvoctrainExpr *expr, int act_lesson,
 }
 
 
-QString QueryManager::compStr (CompType type)
+QString QueryManager::compStr(Prefs::EnumCompType::type type)
 {
    QString str = "???";
-   switch (type) {
-    case DontCare: str = i18n("Don`t Care"); break;
+   switch (type)
+   {
+    case DontCare: str = i18n("Do not Care"); break;
     case WorseThan: str = i18n("Worse Than"); break;
     case WorseEqThan: str = i18n("Equal/Worse Than"); break;
     case MoreThan: str = i18n(">"); break;
@@ -565,7 +436,7 @@ QString QueryManager::typeStr (const QString id)
 
 bool QueryManager::compareBlocking (int grade, int date, bool use_it)
 {
-   time_t cmp = blockItem(grade);
+   time_t cmp = Prefs::blockItem(grade);
    if (grade == KV_NORM_GRADE || cmp == 0 || !use_it) // don't care || all off
      return true;
    else {
@@ -577,7 +448,7 @@ bool QueryManager::compareBlocking (int grade, int date, bool use_it)
 
 bool QueryManager::compareExpiring (int grade, int date, bool use_it)
 {
-   time_t cmp = expireItem(grade);
+   time_t cmp = Prefs::expireItem(grade);
    if (grade == KV_NORM_GRADE || cmp == 0 || !use_it) // don't care || all off
      return false;
    else {
@@ -601,7 +472,7 @@ bool QueryManager::compareDate (CompType type, time_t qd, time_t limit)
     case Within: erg = qd >= now-limit;           // newer date
     break;
 
-    case NotQueried: erg = qd == 0;    
+    case NotQueried: erg = qd == 0;
     break;
 
     default:
@@ -633,7 +504,7 @@ bool QueryManager::compareQuery (CompType type, int qgrade, int limit)
     case LessEqThan: erg = qgrade <= limit;   // sel has less count
     break;
 
-    case LessThan: erg = qgrade < limit;   
+    case LessThan: erg = qgrade < limit;
     break;
 
     default:
@@ -653,7 +524,7 @@ bool QueryManager::compareBad (CompType type, int bcount, int limit)
     case MoreThan: erg = bcount > limit;    // sel has higher bad count
     break;
 
-    case MoreEqThan: erg = bcount >= limit; 
+    case MoreEqThan: erg = bcount >= limit;
     break;
 
     case EqualTo: erg = bcount == limit;
@@ -665,7 +536,7 @@ bool QueryManager::compareBad (CompType type, int bcount, int limit)
     case LessEqThan: erg = bcount <= limit;   // sel has less count
     break;
 
-    case LessThan: erg = bcount < limit; 
+    case LessThan: erg = bcount < limit;
     break;
 
     default:
@@ -707,7 +578,7 @@ bool QueryManager::compareGrade (CompType type, grade_t qgrade, grade_t limit)
 }
 
 
-bool QueryManager::compareType (CompType type, QString exprtype, QString limit)
+bool QueryManager::compareType (CompType type, const QString & exprtype, const QString & limit)
 {
    bool erg = true;
    switch (type) {
@@ -774,17 +645,18 @@ void QueryManager::setTypeNames (vector<QString> names)
 }
 
 
-void QueryManager::setLessonItemStr (QString indices)
+void QueryManager::setLessonItemStr (const QString & indices)
 {
   int pos;
+  QString indices_copy = indices;
   lessonitems.clear();
-  while ((pos = indices.find(' ')) >= 0) {
-     QString s = indices.left(pos);
-     indices.remove(0, pos+1);
+  while ((pos = indices_copy.find(' ')) >= 0) {
+     QString s = indices_copy.left(pos);
+     indices_copy.remove(0, pos+1);
      lessonitems.push_back(s.toInt());
   }
-  if (indices.length() != 0) {
-    lessonitems.push_back(indices.toInt());
+  if (indices_copy.length() != 0) {
+    lessonitems.push_back(indices_copy.toInt());
   }
 }
 
