@@ -1,16 +1,14 @@
 /***************************************************************************
 
-    $Id: kvd_vcb.cpp,v 1.8 2003/07/17 12:48:21 binner Exp $
-
                    maintain a document in vocabbox format
 
     -----------------------------------------------------------------------
 
-    begin                : Thr Mar 23 21:00:53 MET 1999
-                                           
-    copyright            : (C) 1999-2001 Ewald Arnold
-                           (C) 2001 The KDE-EDU team
-    email                : kvoctrain@ewald-arnold.de
+    begin          : Thr Mar 23 21:00:53 MET 1999
+
+    copyright      : (C) 1999-2001 Ewald Arnold <kvoctrain@ewald-arnold.de>
+                     (C) 2001 The KDE-EDU team
+                     (C) 2004 Peter Hedlund <peter.hedlund@kdemail.net>
 
     -----------------------------------------------------------------------
 
@@ -21,7 +19,7 @@
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   * 
+ *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
 
@@ -32,34 +30,33 @@
 #include "kvoctraindoc.h"
 #include "kvoctraincore.h"
 
-#include <qtextstream.h>
 
 
-bool kvoctrainDoc::saveTypeNameVcb (QTextStream &os)
+bool kvoctrainDoc::saveTypeNameVcb (QTextStream &/*os*/)
 {
  return true;
 }
 
 
-bool kvoctrainDoc::loadTypeNameVcb (QTextStream &is)
+bool kvoctrainDoc::loadTypeNameVcb (QTextStream &/*is*/)
 {
  return true;
 }
 
 
-bool kvoctrainDoc::saveLessonVcb (QTextStream &os)
+bool kvoctrainDoc::saveLessonVcb (QTextStream &/*os*/)
 {
  return true;
 }
 
 
-bool kvoctrainDoc::loadLessonVcb (QTextStream &is)
+bool kvoctrainDoc::loadLessonVcb (QTextStream &/*is*/)
 {
  return true;
 }
 
 
-bool kvoctrainDoc::saveToVcb (QTextStream& os, QString &title)
+bool kvoctrainDoc::saveToVcb (QTextStream& os, QString &/*title*/)
 {
   saveTypeNameVcb (os);
   saveLessonVcb (os);
@@ -74,7 +71,7 @@ bool kvoctrainDoc::saveToVcb (QTextStream& os, QString &title)
 
     ent_no++;
     if (ent_percent != 0 && (ent_no % ent_percent) == 0 )
-      emit progressChanged(this, ent_no / f_ent_percent);
+      emit progressChanged(this, int(ent_no / f_ent_percent));
 
     QString s, exp;
 
@@ -117,7 +114,7 @@ bool kvoctrainDoc::loadFromVcb (QTextStream& is)
     ln--;
     if (ln <= 0) {
       ln = size / 40 / 100;  // assume each line about 40 chars
-      emit progressChanged(this, is.device()->at() / f_ent_percent);
+      emit progressChanged(this, int(is.device()->at() / f_ent_percent));
     }
 
     if (!s.stripWhiteSpace().isEmpty()) {
@@ -126,7 +123,7 @@ bool kvoctrainDoc::loadFromVcb (QTextStream& is)
               tgrade = KV_LEV1_GRADE;
       size_t  odate = time(0),
               tdate = time(0);
- 
+
       int pos = s.find (VCB_SEPARATOR);
       if (pos >= 0) {
         o = s.left(pos);
@@ -141,29 +138,29 @@ bool kvoctrainDoc::loadFromVcb (QTextStream& is)
       else {
         t = s;
       }
- 
+
       pos = s.find (VCB_SEPARATOR);
       if (pos >= 0) {
         ograde = s.left(pos).toInt();
         s.remove (0, pos+QString(VCB_SEPARATOR).length());
       }
- 
+
       pos = s.find (VCB_SEPARATOR);
       if (pos >= 0) {
         tgrade = s.left(pos).toInt();
         s.remove (0, pos+QString(VCB_SEPARATOR).length());
       }
- 
+
       pos = s.find (VCB_SEPARATOR);
       if (pos >= 0) {
         odate = s.left(pos).toInt();
         s.remove (0, pos+QString(VCB_SEPARATOR).length());
       }
- 
-      if (s.stripWhiteSpace().length() >= 0) {
+
+      if (s.stripWhiteSpace().length() > 0) {
         tdate = s.toInt();
       }
- 
+
       kvoctrainExpr bucket;
       bucket.setOriginal(o);
       bucket.addTranslation(t);
@@ -173,12 +170,12 @@ bool kvoctrainDoc::loadFromVcb (QTextStream& is)
         bucket.setQueryCount(1, 1, false);
 
       bucket.setGrade(1, tgrade, true);
-      if (tgrade != 0) 
+      if (tgrade != 0)
         bucket.setQueryCount(1, 1, true);
 
       bucket.setQueryDate(1, odate, false);
       bucket.setQueryDate(1, tdate, true);
- 
+
       appendEntry (&bucket);
     }
   }
@@ -191,7 +188,7 @@ bool kvoctrainDoc::loadFromVcb (QTextStream& is)
 }
 
 
-void kvoctrainDoc::errorVcb (int line, const QString &text )
+void kvoctrainDoc::errorVcb (int /*line*/, const QString &text )
 {
    unknown_elem = true;
    QApplication::setOverrideCursor( arrowCursor, true );
