@@ -1,5 +1,5 @@
 /* This file is part of KWordQuiz
-  Copyright (C) 2003 Peter Hedlund <peter@peterandlinda.com>
+  Copyright (C) 2003 Peter Hedlund <peter.hedlund@kdemail.net>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
@@ -12,8 +12,8 @@
 
   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-  Boston, MA 02111-1307, USA.
+  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+  Boston, MA 02110-1301, USA.
 */
 
 #include <qlabel.h>
@@ -41,7 +41,7 @@ QString highlightError(const QString & c, const QString & e)
   QString result2 = "</qt>";
   int j = s.length() - 1;
   int k = e.length() - 1;
-  while (s[j] == e[k])
+  while (s[j] == e[k] && k > i)
   {
     result2.prepend(e[k]);
     j--;
@@ -65,6 +65,7 @@ QAView::QAView(QWidget *parent, const char *name, WFlags f):QAViewBase(parent, n
 
 QAView::~QAView()
 {
+  delete txtAnswer; //Fixes #122110 on PCLOS and Ubuntu
 }
 
 void QAView::setQuiz(WQQuiz *quiz)
