@@ -46,20 +46,32 @@ uint ExtDate::m_monthLength[] = {31, 28, 31, 30,  31,  30,  31,  31,  30,  31,
 uint ExtDate::m_monthOrigin[] = { 0, 30, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334};
 
 QString ExtDate::m_shortMonthNames[12] = {
-	i18n("Jan"), i18n("Feb"), i18n("Mar"), i18n("Apr"), i18n("May"), i18n("Jun"),
-	i18n("Jul"), i18n("Aug"), i18n("Sep"), i18n("Oct"), i18n("Nov"), i18n("Dec")
+	i18n("Short month name", "Jan"), i18n("Short month name", "Feb"), 
+	i18n("Short month name", "Mar"), i18n("Short month name", "Apr"), 
+	i18n("Short month name", "May"), i18n("Short month name", "Jun"),
+	i18n("Short month name", "Jul"), i18n("Short month name", "Aug"), 
+	i18n("Short month name", "Sep"), i18n("Short month name", "Oct"), 
+	i18n("Short month name", "Nov"), i18n("Short month name", "Dec")
 };
 QString ExtDate::m_shortDayNames[7] = {
-	i18n("Mon"), i18n("Tue"), i18n("Wed"), i18n("Thu"), i18n("Fri"), i18n("Sat"), i18n("Sun")
+	i18n("Short day name", "Mon"), i18n("Short day name", "Tue"), 
+	i18n("Short day name", "Wed"), i18n("Short day name", "Thu"), 
+	i18n("Short day name", "Fri"), i18n("Short day name", "Sat"), 
+	i18n("Short day name", "Sun")
 };
 QString ExtDate::m_longMonthNames[12] = {
-	i18n("January"), i18n("February"), i18n("March"), i18n("April"), i18n("May"),
-	i18n("June"), i18n("July"), i18n("August"), i18n("September"), i18n("October"),
-	i18n("November"), i18n("December")
+	i18n("Long month name", "January"), i18n("Long month name", "February"), 
+	i18n("Long month name", "March"), i18n("Long month name", "April"), 
+	i18n("Long month name", "May"), i18n("Long month name", "June"), 
+	i18n("Long month name", "July"), i18n("Long month name", "August"), 
+	i18n("Long month name", "September"), i18n("Long month name", "October"),
+	i18n("Long month name", "November"), i18n("Long month name", "December")
 };
 QString ExtDate::m_longDayNames[7] = {
-	i18n("Monday"), i18n("Tuesday"), i18n("Wednesday"), i18n("Thursday"),
-	i18n("Friday"), i18n("Saturday"), i18n("Sunday")
+	i18n("Long day name", "Monday"), i18n("Long day name", "Tuesday"), 
+	i18n("Long day name", "Wednesday"), i18n("Long day name", "Thursday"),
+	i18n("Long day name", "Friday"), i18n("Long day name", "Saturday"), 
+	i18n("Long day name", "Sunday")
 };
 
 ExtDate::ExtDate( int y, int m, int d)
